@@ -6,6 +6,7 @@ safer for L<MooseX::Types>
 =cut
 
 package MooseX::Types::CheckedUtilExports;
+our $VERSION = "0.21";
 
 use strict;
 use warnings;
@@ -45,10 +46,6 @@ From L<Moose::Util::TypeConstraints>. See that module for syntax.
 
 =cut
 
-Moose::Exporter->setup_import_methods(
-    with_caller => [ @exports, 'class_type', 'role_type' ]
-);
-
 for my $export (@exports) {
     no strict 'refs';
 
@@ -67,6 +64,10 @@ for my $export (@exports) {
     }
 }
 
+Moose::Exporter->setup_import_methods(
+    with_caller => [ @exports, 'class_type', 'role_type' ]
+);
+
 sub class_type {
     my $caller = shift;
 
@@ -87,6 +88,10 @@ sub role_type ($;$) {
 
 L<MooseX::Types>
 
+=head1 AUTHOR
+
+See L<MooseX::Types/AUTHOR>.
+
 =head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify
