@@ -1,4 +1,5 @@
 package MooseX::Types::Moose;
+our $VERSION = "0.21";
 
 =head1 NAME
 
@@ -69,10 +70,9 @@ L<MooseX::Types::Moose>,
 L<Moose>, 
 L<Moose::Util::TypeConstraints>
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-Robert 'phaylon' Sedlacek C<E<lt>rs@474.atE<gt>>, with many thanks to
-the C<#moose> cabal on C<irc.perl.org>.
+See L<MooseX::Types/AUTHOR>.
 
 =head1 LICENSE
 
