@@ -1,4 +1,5 @@
 package MooseX::Types::TypeDecorator;
+our $VERSION = "0.21";
 
 use strict;
 use warnings;
@@ -204,9 +205,9 @@ sub AUTOLOAD {
     }
 }
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-John Napiorkowski (jnapiorkowski) <jjnapiork@cpan.org>
+See L<MooseX::Types/AUTHOR>.
 
 =head1 LICENSE
 
