@@ -5,6 +5,7 @@ MooseX::Types::Wrapper - Wrap exports from a library
 =cut
 
 package MooseX::Types::Wrapper;
+our $VERSION = "0.21";
 use Moose;
 
 use Carp::Clan      qw( ^MooseX::Types );
@@ -51,10 +52,9 @@ sub import {
 
 L<MooseX::Types>
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-Robert 'phaylon' Sedlacek C<E<lt>rs@474.atE<gt>>, with many thanks to
-the C<#moose> cabal on C<irc.perl.org>.
+See L<MooseX::Types/AUTHOR>.
 
 =head1 LICENSE
 
